@@ -21,6 +21,7 @@
 
 #include "scale/commons.h"
 #include "scale/iterator.h"
+#include "scale/xtable.h"
 
 
 typedef struct _sc_btree sbtree_t;
@@ -46,9 +47,12 @@ sbtree_t *		s_btree_alloc(sc_compf_t compare);
 void			s_btree_free(sbtree_t *btree);
 size_t			s_btree_size(const sbtree_t *btree);
 void			s_btree_add(sbtree_t *btree, spointer key, spointer conts);
-spointer		s_btree_get(sbtree_t *btree, const spointer key);
+spointer		s_btree_get(const sbtree_t *btree, const spointer key);
 spointer		s_btree_remove(sbtree_t *btree, const spointer key);
-siterator_t *	s_btree_lfs_iterator(sbtree_t *btree);
+siterator_t *	s_btree_lfs_iterator(const sbtree_t *btree);
+
+sxtable_t *		s_btree_attach_xtable(sbtree_t *btree);
+sxtable_t *		s_btree_xtable(sc_compf_t cmpf);
 
 
 
