@@ -28,6 +28,7 @@
 
 #include "scale/commons.h"
 #include "scale/iterator.h"
+#include "scale/xtable.h"
 
 
 /*
@@ -49,7 +50,14 @@ void			s_hash_remove(shash_t *htable, const spointer key);
 size_t			s_hash_size(shash_t *htable);
 void			s_hash_clear(shash_t *htable);
 
-siterator_t *	s_hash_keys(shash_t *htable);
+
+siterator_t *s_hash_keys(shash_t *htable);
+
+/** $BCj>]%F!<%V%k$KJQ49(B */
+sxtable_t *s_hash_xtable(size_t hsize, hashfunc_t hfunc, sc_compf_t cmpf);
+
+/** $B4{B8$N%O%C%7%e$rCj>]%F!<%V%k$K%"%?%C%A$9$k(B */
+sxtable_t *s_hash_attach_xtable(shash_t *hash);
 
 /* use this function for hashfunc_t. */
 unsigned int	s_string_hashfunc(const spointer key, size_t hashsize);
