@@ -1,7 +1,10 @@
 /*
- * $Id: stack.h,v 1.6 2004/07/10 17:04:48 jklein Exp $
+ * $Id: stack.h,v 1.7 2004/07/22 17:27:56 jklein Exp $
  * $Author: jklein $
  * $Log: stack.h,v $
+ * Revision 1.7  2004/07/22 17:27:56  jklein
+ * few changes in stack.h
+ *
  * Revision 1.6  2004/07/10 17:04:48  jklein
  * Added few function to sxarray_t.
  *
@@ -39,7 +42,8 @@ typedef svector_t sstack_t;
 #define s_stack_free(s)			s_vector_free((svector_t *)(s))
 #define s_stack_size(s)			s_vector_size((svector_t *)(s))
 #define s_stack_push(s, c)		s_vector_add((svector_t *)(s), c)
-#define s_stack_find(s, c, f)	s_vector_find((svector_t *)(s), c, f);
+#define s_stack_find(s, c, f)	s_vector_find((svector_t *)(s), c, f)
+#define s_stack_get(s, i)		s_vector_get((svector_t *)(s), i)
 
 spointer		s_stack_peek(sstack_t *);
 spointer		s_stack_pop(sstack_t *);
