@@ -13,6 +13,7 @@
 
 #include "scale/hash.h"
 #include "scale/alloc.h"
+#include "scale/xtable.h"
 
 
 typedef struct _sc_hash_elt shash_elt_t;
@@ -90,17 +91,12 @@ s_hash_put(shash_t *htable, spointer key, spointer obj)
 
 /* This function doesn't remove object.
  * It only takes out from a hash-table.
- * So, you have to free it in you own reponsibility.
- */
+ * So, you have to free it in you own reponsibility. */
 void
 s_hash_remove(shash_t *htable, const spointer key)
 {
-	shash_elt_t *elt, *prev;
-	unsigned int hashkey;
-
-	elt = prev = NULL;
-
-	hashkey = htable->hash(key, htable->hashsize);
+	shash_elt_t *elt = NULL, *prev = NULL;
+	const unsigned int hashkey = htable->hash(key, htable->hashsize);;
 
 	for(elt = htable->table[hashkey]; elt; elt=elt->next) {
 		if(htable->cmp(elt->key, key) == 0) {
@@ -238,7 +234,6 @@ _s_hash_iterator_free(siterator_t *itr)
 }
 
 
-
 siterator_t *
 s_hash_keys(shash_t *htable)
 {
@@ -256,3 +251,89 @@ s_hash_keys(shash_t *htable)
 
 	return itr;
 }
+
+
+/* for xtable_t */
+
+
+#define GET_HASH(xt) ((shash_t *)xt->tabledata)
+
+
+static void
+_s_hash_xtable_free(sxtable_t *xt)
+{
+	shash_t *hash = GET_HASH(xt);
+
+	if (xt->is_origin)
+		s_hash_free(hash);
+	s_freen(xt, sizeof(sxtable_t));
+}
+
+
+static size_t
+_s_hash_xtable_size(const sxtable_t *xt)
+{
+	return s_hash_size(GET_HASH(xt));
+}
+
+
+static void
+_s_hash_xtable_put(sxtable_t *xt, spointer key, spointer contents)
+{
+	s_hash_put(GET_HASH(xt), key, contents);
+}
+
+
+static spointer
+_s_hash_xtable_get(const sxtable_t *xt, const spointer key)
+{
+	return s_hash_get(GET_HASH(xt), key);
+}
+
+
+static void
+_s_hash_xtable_remove(sxtable_t *xt, const spointer key)
+{
+	s_hash_remove(GET_HASH(xt), key);
+}
+
+
+static siterator_t *
+_s_hash_xtable_keys(const sxtable_t *xt)
+{
+	return s_hash_keys(GET_HASH(xt));
+}
+
+
+sxtable_t *
+s_hash_attach_xtable(shash_t *hash)
+{
+	sxtable_t *xt;
+
+	xt = typed_malloc(sxtable_t);
+	xt->tabledata = hash;
+	xt->is_origin = false;
+	xt->free = _s_hash_xtable_free;
+	xt->size = _s_hash_xtable_size;
+	xt->put  = _s_hash_xtable_put;
+	xt->get  = _s_hash_xtable_get;
+	xt->remove = _s_hash_xtable_remove;
+	xt->keys = _s_hash_xtable_keys;
+
+	return xt;
+}
+
+
+sxtable_t *
+s_hash_xtable(size_t hsize, hashfunc_t hfunc, sc_compf_t cmpf)
+{
+	sxtable_t *xt;
+	shash_t *hash;
+
+	hash = s_hash_alloc(hsize, hfunc, cmpf);
+	xt = s_hash_attach_xtable(hash);
+	xt->is_origin = true;
+
+	return xt;
+}
+
