@@ -1,7 +1,10 @@
 /*
- * $Id: sc_vector.c,v 1.9 2004/07/22 17:27:56 jklein Exp $
+ * $Id: sc_vector.c,v 1.10 2004/08/02 16:38:01 jklein Exp $
  * $Author: jklein $
  * $Log: sc_vector.c,v $
+ * Revision 1.10  2004/08/02 16:38:01  jklein
+ * Fixed bug in the btree.c
+ *
  * Revision 1.9  2004/07/22 17:27:56  jklein
  * few changes in stack.h
  *
@@ -40,8 +43,9 @@ _s_vector_grouth(svector_t *vect, size_t tsize)
 	if (vect->memsize >= tsize)
 		return; /* nothiong to do. */
 
-	vect->array = (spointer *)s_reallocn(vect->array, vect->memsize,
-										 sizeof(spointer)*tsize);
+	vect->array = (spointer *)s_reallocn(vect->array,
+										 sizeof(spointer) * vect->memsize,
+										 sizeof(spointer) * tsize);
 	vect->memsize = tsize;
 }
 
@@ -180,20 +184,6 @@ s_vector_join(svector_t *dst, svector_t *src)
 }
 
 
-#include <stdio.h>
-static void
-_s_array_dump(const char *prmpt, spointer list[], int low, int high)
-{
-	uint i;
-
-	printf("%s [%d -> %d] ", prmpt, low, high);
-
-	for (i=low; i<=high; i++)
-		printf("%s, ", (char *)list[i]);
-	printf("\n");
-}
-
-
 static void
 _s_vector_qsort(spointer list[], int low, int high, sc_compf_t cmpf)
 {
