@@ -1,7 +1,10 @@
 /**
- * $Id: tester.c,v 1.11 2004/07/22 17:27:56 jklein Exp $
+ * $Id: tester.c,v 1.12 2004/08/02 16:39:13 jklein Exp $
  * $Author: jklein $
  * $Log: tester.c,v $
+ * Revision 1.12  2004/08/02 16:39:13  jklein
+ * Fixed bug in the btree.c
+ *
  * Revision 1.11  2004/07/22 17:27:56  jklein
  * few changes in stack.h
  *
@@ -249,6 +252,74 @@ sxarray_tester(sxarray_t *xarr)
 }
 
 
+int
+sxtable_test(sxtable_t *xt)
+{
+	assert(s_xtable_size(xt) == 0);
+
+	s_xtable_put(xt, "a", "A");
+	s_xtable_put(xt, "b", "B");
+	s_xtable_put(xt, "c", "C");
+
+	assert(s_xtable_size(xt) == 3);
+
+	assert(strcmp(s_xtable_get(xt, "a"), "A") == 0);
+	assert(strcmp(s_xtable_get(xt, "b"), "B") == 0);
+	assert(strcmp(s_xtable_get(xt, "c"), "C") == 0);
+
+	s_xtable_remove(xt, "a");
+	s_xtable_remove(xt, "b");
+	s_xtable_remove(xt, "c");
+
+	assert(s_xtable_size(xt) == 0);
+
+	{/* test iterator */
+		siterator_t *keys;
+		char *key;
+		int has_read = 1 | 2 | 4 | 8;
+
+		s_xtable_put(xt, "1", "a");
+		s_xtable_put(xt, "2", "b");
+		s_xtable_put(xt, "4", "c");
+		s_xtable_put(xt, "8", "d");
+
+		assert(keys = s_xtable_keys(xt));
+
+		while ( (key = s_iterator_next(keys)) != NULL) {
+			if (strcmp(key, "1") == 0) {
+				if (has_read & 1)
+					fprintf(stderr, "ERROR(%d)\n", __LINE__);
+				has_read = has_read & ~1;
+			}
+			else if (strcmp(key, "2") == 0) {
+				if (has_read & 2)
+					fprintf(stderr, "ERROR(%d)\n", __LINE__);
+				has_read = has_read & ~2;
+			}
+			else if (strcmp(key, "4") == 0) {
+				if (has_read & 4)
+					fprintf(stderr, "ERROR(%d)\n", __LINE__);
+				has_read = has_read & ~4;
+			}
+			else if (strcmp(key, "8") == 0) {
+				if (has_read & 8)
+					fprintf(stderr, "ERROR(%d)\n", __LINE__);
+				has_read = has_read & ~8;
+			}
+		}
+
+		if (has_read != 0) {
+			fprintf(stderr, "not read all\n");
+			return 0;
+		}
+
+		s_iterator_free(keys);
+	}
+
+	return 1;
+}
+
+
 int
 test_list(void)
 {
@@ -537,6 +608,15 @@ test_hash(void)
 		itr->free(itr);
 	}
 
+	s_hash_remove(hash, "a");
+	s_hash_remove(hash, "c");
+
+	{
+		sxtable_t *xt = s_hash_attach_xtable(hash);
+		sxtable_test(xt);
+		s_xtable_free(xt);
+	}
+
 	s_hash_free(hash);
 	FUNC_END();
 	return 1;
@@ -676,7 +756,6 @@ test_btree(void)
 	s_btree_add(btree, "k", "E");
 	assert(s_btree_size(btree) == 11);
 
-
 	assert(strcmp(s_btree_get(btree, "a"), "A") == 0);
 	assert(strcmp(s_btree_get(btree, "b"), "B") == 0);
 	assert(strcmp(s_btree_get(btree, "c"), "C") == 0);
@@ -714,6 +793,16 @@ test_btree(void)
 		iterator_tester(itr);
 
 		itr->free(itr);
+
+		assert(strcmp(s_btree_remove(btree, "A"), "a") == 0);
+		assert(strcmp(s_btree_remove(btree, "B"), "b") == 0);
+		assert(strcmp(s_btree_remove(btree, "C"), "c") == 0);
+	}
+
+	{
+		sxtable_t *xt = s_btree_attach_xtable(btree);
+		sxtable_test(xt);
+		s_xtable_free(xt);
 	}
 
 	s_btree_free(btree);
